<?PHP
/**
 * Endpoint Manager FreePBX File
 *
 * @author Andrew Nagy
 * @license MPL / GPLv2 / LGPL
 * @package Endpoint Manager
 */

require_once dirname(__FILE__).'/config.php';

include LOCAL_PATH.'includes/template_manager.inc';	