<h2>Package Manager</h2>
<table align='center' width='100%'>
<tr>
    <td align='center'>{if condition="$subhead_area == 'manager'"}<h4 style="color:#ff9933;"><?php echo _('Install/Uninstall Brands/Models')?></h4>{else}<h4><a href='config.php?type=tool&amp;display=epm_config&amp;subpage=manager'><?php echo _('Install/Uninstall Brands/Models')?></a></h4>{/if}</td>
    <td align='center'>{if condition="$subhead_area == 'editor'"}<h4 style="color:#ff9933;"><?php echo _('Show/Hide Brands/Models')?></h4>{else}<h4><a href='config.php?type=tool&amp;display=epm_config&amp;subpage=editor'><?php echo _('Show/Hide Brands/Models')?></a></h4>{/if}</td>
</tr>
</table>
<hr>
