/* 
	Using a customized version of Eric Meyer's CSS Reset to give us an even, cross-browser playing field. More info:
	http://meyerweb.com/eric/thoughts/2007/05/01/reset-reloaded/
*/

html, body, div, span, applet, object, iframe,
h1, h2, h3, h4, h5, h6, p, blockquote, pre,
a, abbr, acronym, address, big, cite, code,
del, dfn, em, font, img, ins, kbd, q, s, samp,
small, strike, strong, sub, sup, tt, var,
b, u, i, center,
dl, dt, dd, ol, ul, li,
fieldset, form, label, legend,
table, caption, tbody, tfoot, thead, tr, th, td {
	background: transparent;
	border: 0;
	font-size: 99%;
	font-family: Arial;
	margin: 0;
	outline: 0;
	padding: 0;
	vertical-align: baseline;
}
body {
	line-height: 1.2;
}
ol, ul {
	margin-left: 25px;
}

:focus {
	outline: 1px #c0c dotted;
}