<div style="background-color:#f8f8ff; border: 1px solid #aaaaff; padding:10px;font-family:arial;color:{if condition="$fatal_error == 1"}red{else}grey{/if};font-size:20px;text-align:center"><b>{$error_message}</b>{if condition="$advanced_debug == 1"}<br /><h5 style="font-family:arial;color:black;font-size:12px;text-align:left"><pre><u>Backtrace</u><br /><?php echo debug_print_backtrace();?><br /><u>Extended Backtrace</u><br /><?php echo var_dump(debug_backtrace());?><br /><u>Last Error</u><br /><?php echo print_r(error_get_last());?></pre></h5>{/if}</div>