<table align='center' width='90%'>
<tr>
<td align='center'><h3><a href='?type=tool&display=endpointman&page=devices_manager'><?php echo _("My Devices List")?></a></h3></td>
<td align='center'><h3><a href='?type=tool&display=endpointman&page=template_manager'><?php echo _("Template Manager")?></a></h3></td>
<td align='center'><h3><a href='?type=tool&display=endpointman&page=brand_model_manager'><?php echo _("Brand Configurations/Setup")?></a></h3></td>
<td align='center'><h3><a href='?type=tool&display=endpointman&page=advanced'><?php echo _("Advanced Settings")?></a></h3></td>
</tr>
</table>
<hr width='90%'>
