<?PHP
/**
 * Endpoint Manager FreePBX Sub-Module Installer
 *
 * @author Andrew Nagy
 * @license MPL / GPLv2 / LGPL
 * @package Endpoint Manager
 */
echo "<!DOCTYPE html>";
include('includes/popup.inc');
