{if condition="isset($show_error_box)"}
    {include="message_box"}
{/if}
<h4><?php echo _('Export CSV')?></h4>
<p><?php echo _('Export CSV file of devices')?>.</p>
<a href="{$exporter_address}"><button type="button" name="button_export"><i class='icon-mail-forward'></i> <?php echo _('Export')?></a></button>

<h4><?php echo _('Import CSV')?></h4>
<form name="form1" enctype="multipart/form-data" method="post" action="config.php?type=tool&display=epm_advanced&subpage=iedl&action=import">
  <p><?php echo _('Import CSV file of devices')?>.</p>
  <button type="submit" name="button_import"><i class='icon-mail-reply'></i> <?php echo _('Import')?></a></button>
  <label>
	<input type="hidden" name="MAX_FILE_SIZE" value="30000" />
    <input type="file" name="import_csv" id="fileField">
  </label>
</form>
<font style="font-size: 0.8em"><i class='icon-warning-sign'></i><strong>Warning:</strong> The extensions need to be added into FreePBX before you import.</font></p>

<h5><?php echo _('CSV File Format')?></h5>
<code class='inline'>&lt;<?php echo _('MAC Address')?>&gt;,&lt;<?php echo _('Brand')?>&gt;,&lt;<?php echo _('Model')?>&gt;,&lt;<?php echo _('Extension')?>&gt;,&lt;<?php echo _('Line')?>&gt;</code>
<ul class='nobullets'>
<li><code class='inline'><?php echo _('MAC Address')?></code> - <?php echo _('is required')?></li>
<li><code class='inline'><?php echo _('Brand')?></code> - <?php echo _('can be blank')?></li>
<li><code class='inline'><?php echo _('Model')?></code> - <?php echo _('can be blank')?></li>
<li><code class='inline'><?php echo _('Extension')?></code> - <?php echo _('can be blank')?></li>
<li><code class='inline'><?php echo _('Line')?></code> - <?php echo _('can be blank')?></li>
</ul>
<h6><?php echo _('Examples')?>:</h6>
<code class='inline'>001122334455,Cisco/Linksys,7940,4321,1</code><br/>
<code class='inline'>112233445566,Cisco/Linksys,7945,,</code>
