/* 
    Document   : main.css
    Created on : Feb 7, 2011, 3:12:27 AM
    Author     : Andrew
    Description:
        Purpose of the stylesheet follows.
*/

/* 
   TODO customize this sample style
   Syntax recommendation http://www.w3.org/TR/REC-CSS2/
*/


