<style type="text/css">
<!--
.brand {
    margin-top: 10px;
}
.product {
    margin-top: 10px;
}
button {
    width: 68px;
}
-->
</style>
{loop name="brand2_list"}
<form class="brand" action='config.php?type=tool&amp;display=epm_config&amp;subpage=editor' method='POST'><input type="hidden" name="brand" value="{$value.id}"><button type="submit" name="button_{if condition="$value.hidden == '1'"}show{else}hide{/if}" class="button_{if condition="$value.hidden == '1'"}show button_Enable{else}hide button_Disable{/if}">{if condition="$value.hidden == '1'"}<i class='icon-plus green'></i> <?php echo _('Show')?>{else}<i class='icon-minus red'></i> <?php echo _('Hide')?>{/if}</button> <font style='font-size: 1.2em; vertical-align: middle'><b>{$value.name}</b></font></form>
{if condition="$value.hidden == '0'"}
<table width="100%" border="0" cellspacing="0" cellpadding="0">
  <tr>
    <td width="3%">&nbsp;</td>
    <td width="97%">{loop name="value.products"}
    <table width="100%" class="product alt_table" border="0" cellspacing="0" cellpadding="0">
      <tr>
          <td colspan="2"><form action='config.php?type=tool&amp;display=epm_config&amp;subpage=editor' method='POST'><input type="hidden" name="product" value="{$value.id}"><button type="submit" name="button_{if condition="$value.hidden == '1'"}show{else}hide{/if}" class="button_{if condition="$value.hidden == '1'"}show button_Enable{else}hide button_Disable{/if}">{if condition="$value.hidden == '1'"}<i class='icon-plus green'></i> <?php echo _('Show')?>{else}<i class='icon-minus red'></i> <?php echo _('Hide')?>{/if}</button> <b>{$value.long_name}</b></form></td>
      </tr>
      <tr>
        <td width="4%">&nbsp;</td>
        <td width="96%">{loop name="value.models"}
        <table width="100%" class="model" border="0" cellspacing="0" cellpadding="0">
          <tr>
            <td><form action='config.php?type=tool&amp;display=epm_config&amp;subpage=editor' method='POST'><input type="hidden" name="model" value="{$value.id}"><button type="submit" name="button_{if condition="$value.hidden == '1'"}show{else}hide{/if}" class="button_{if condition="$value.hidden == '1'"}Show button_Enable{else}Hide button_Disable{/if}">{if condition="$value.hidden == '1'"}<i class='icon-plus green'></i> <?php echo _('Show')?>{else}<i class='icon-minus red'></i> <?php echo _('Hide')?>{/if}</button> {$value.model}</form></td>
          </tr>
        </table>{/loop}</td>
      </tr>
    </table>{/loop}</td>
  </tr>
</table>
{/if}
{/loop}
