/* 
    Document   : main.css
    Created on : Feb 7, 2011, 3:12:27 AM
    Author     : Andrew
    Description:
        Purpose of the stylesheet follows.
*/

/* 
   TODO customize this sample style
   Syntax recommendation http://www.w3.org/TR/REC-CSS2/
*/

.red, .error {
  color: #d9534f;
  font-color: #d9534f;
}

.green, .success {
  color: #5cb85c;
  font-color: #5cb85c;
}

.yellow, .warning {
  color: #f0ad4e;
  font-color: #f0ad4e;
}

.cyan, .info {
  color: #5bc0de;
  font-color: #5bc0de;
}

.blue, .primary {
  color: #428bca;
  font-color: #428bca;
}

.gray, .disabled {
  color: #474949;
  font-color: #474949;
}

code.inline {
  padding: 2px 4px;
  font-size: 0.8em;
  background-color: #f7f7f9;
  border: 1px solid #e1e1e8;
}

ul.nobullets {
    list-style-type: none;
}

li {
  line-height: 24px;
}

.button_Enable {
  background: none;
  color: #003300;
  background-color: #66F966;
}

.button_Disable {
  background: none;
  color: #330000;
  background-color: #F96666;
}
