<h2>Advanced Settings</h2>
<table align='center' width='100%'>
<tr>
    <td align='center'>{if condition="$subhead_area == 'settings'"}<h4 style="color:#ff9933;"><?php echo _('Settings')?></h4>{else}<h4><a href='config.php?type=tool&amp;display=epm_advanced&amp;subpage=settings'><?php echo _('Settings')?></a></h4>{/if}</td>
    <td align='center'>{if condition="$subhead_area == 'oui_manager'"}<h4 style="color:#ff9933;"><?php echo _('OUI Manager')?></h4>{else}<h4><a href='config.php?type=tool&amp;display=epm_advanced&amp;subpage=oui_manager'><?php echo _('OUI Manager')?></a></h4>{/if}</td>
    <td align='center'>{if condition="$subhead_area == 'poce'"}<h4 style="color:#ff9933;"><?php echo _('Product Configuration Editor')?></h4>{else}<h4><a href='config.php?type=tool&amp;display=epm_advanced&amp;subpage=poce'><?php echo _('Product Configuration Editor')?></a></h4>{/if}</td>
    <td align='center'>{if condition="$subhead_area == 'iedl'"}<h4 style="color:#ff9933;"><?php echo _('Import/Export My Devices List')?></h4>{else}<h4><a href='config.php?type=tool&amp;display=epm_advanced&amp;subpage=iedl'><?php echo _('Import/Export My Devices List')?></a></h4>{/if}</td>
    <td align='center'>{if condition="$subhead_area == 'manual_upload'"}<h4 style="color:#ff9933;"><?php echo _('Package Import/Export')?></h4>{else}<h4><a href='config.php?type=tool&amp;display=epm_advanced&amp;subpage=manual_upload'><?php echo _('Package Import/Export')?></a></h4>{/if}</td>
</tr>
</table>
<hr>
