{if condition="isset($show_error_box)"}
    {include="message_box"}
{/if}

<table align='center' width='30%' class='alt_table'>
<tr>
  <td align='center'><h3>OUI</h3></td>
  <td align='center'><h3><?php echo _("Brand")?></h3></td>
  <td align='center'></td>
</tr>
{loop name="oui_list"}
<tr>
  <td align='center'><code>{$value.oui}</code></td><td align='center'>{$value.name}</td><td align='center'>
    {if condition="$value.custom == 1"}<a href="config.php?type=tool&amp;display=epm_advanced&amp;subpage=oui_manager&amp;delete=yes&amp;id={$value.id}"><i class='icon-remove red' title='<?php echo _('Delete')?>' border='0'></i></a>{/if}
    </td>
</tr>
{/loop}
</table>

<table align='center' width='30%' class='alt_table'>
<tr>
  <td colspan="3" align='center'><h3><?php echo _('Add Custom')?> OUI</h3></td>
  </form>
  <form action='config.php?type=tool&amp;display=epm_advanced&amp;subpage=oui_manager' method='POST'>
</tr>
<tr>
  <td align='center'><input name="oui" type="text"  maxlength="6"/></td><td align='center'>	<select name="rb_brand">
  {loop name="brand_ava"}
  <option value="{$value.value}">{$value.text}</option>
  {/loop}
  </select></td>
  <td align='center'><button type="submit" name="oui_sub"><i class='icon-plus green'></i> <?php echo _('Add')?></button></td>
  </form>
</tr>
</table>
